@@ -82,7 +82,8 @@ static void proxy_cleanup(void)
 				last->next = a->next;
 			else
 				proxy_requests = a->next;
-
+			if (a->data != NULL)
+				free(a->data);
 			authfree(a);
 
 			continue;
@@ -145,6 +146,8 @@ int proxy_addrequest(AUTH_REQ *authreq, int *proxy_id)
 			last->next = a->next;
 		else
 			proxy_requests = a->next;
+		if (a->data != NULL)
+			free(a->data);
 		authfree(a);
 	}
 	if (id < 0) {
@@ -669,6 +672,7 @@ int proxy_receive(AUTH_REQ *authreq, int activefd) {
 	 *	Now rebuild the AUTHREQ struct, so that the
 	 *	normal functions can process it.
 	 */
+	pairfree(authreq->proxy_pairs);
 	oldreq->server_reply = allowed_pairs;
 	oldreq->server_code  = authreq->code;
 	oldreq->validated    = 1;
