@@ -60,6 +60,7 @@ char radiusd_sccsid[] =
  */
 char			*progname;
 char			*radius_dir;
+char			*dir_prefix = "";
 char			*radlog_dir;
 char			*radacct_dir;
 int			log_stripped_names;
@@ -226,7 +227,7 @@ int main(int argc, char **argv)
 	/*
 	 *	Process the options.
 	 */
-	while((argval = getopt(argc, argv, "ASa:ci:l:d:bfp:m:r:sntu:vxyz")) != EOF) {
+	while((argval = getopt(argc, argv, "ASa:ci:l:d:P:bfp:m:r:sntu:vxyz")) != EOF) {
 
 		switch(argval) {
 
@@ -250,6 +251,10 @@ int main(int argc, char **argv)
 		case 'd':
 			radius_dir = optarg;
 			break;
+
+		case 'P':
+			dir_prefix = optarg;
+			break;
 		
 		case 'f':
 			dontfork = 1;
@@ -628,6 +633,11 @@ int radrespond(AUTH_REQ *authreq, int activefd, SQLSOCK *acctsock) {
 		break;
 	
 	case PW_ACCOUNTING_REQUEST:
+		/* FIXME: The auth process does not like accounting requests */
+		if (radius_pid == getpid()) {
+			DEBUG("Accounting request received in auth process");
+			return 0;
+		}
 		socket = acctsock;
 		fun = rad_accounting;
 		break;
