@@ -8,6 +8,12 @@
 #ifndef SYSDEP_H_INCLUDED
 #define SYSDEP_H_INCLUDED
 
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(bsdi) || defined(M_UNIX)
+#  ifndef NOSHADOW
+#    define NOSHADOW
+#  endif
+#endif
+
 #if defined(__alpha) && (defined(__osf__) || defined(__linux__))
 typedef unsigned int	UINT4;
 #else
@@ -16,14 +22,14 @@ typedef unsigned long	UINT4;
 
 #ifdef BSD
 #include        <strings.h>
+#include	<time.h>
+#include	<sys/time.h>
 #else
 #include        <string.h>
 #endif
 
 #ifdef __FreeBSD__
 # include        <stdlib.h>
-# include	 <time.h>
-# include	 <sys/time.h>
 #else
 # include        <malloc.h>
 #endif  /* FreeBSD */
@@ -47,6 +53,17 @@ typedef unsigned long	UINT4;
 #else
 #  include <utmp.h>
 #endif
+
+#if defined(__hpux) || defined(hpux) || defined(__hpux__)
+#  define UT_NAMESIZE   8
+#  define UT_LINESIZE   12
+#  define UT_HOSTSIZE   16
+#  define setlinebuf(_s)        setvbuf(_s, (char *)0, _IOLBF, 0)
+#  ifndef __hpux__
+#    define __hpux__
+#  endif
+#endif
+
 #ifdef __osf__
 #  define UT_NAMESIZE	32
 #  define UT_LINESIZE	32
