@@ -277,11 +277,15 @@ void pairadd(VALUE_PAIR **first, VALUE_PAIR *new)
  */
 void authfree(AUTH_REQ *authreq)
 {
-	pairfree(authreq->request);
-	pairfree(authreq->check_pairs);
-	pairfree(authreq->reply_pairs);
-	memset(authreq, 0, sizeof(AUTH_REQ));
-	free(authreq);
+	if (authreq != NULL) {
+		pairfree(authreq->request);
+		pairfree(authreq->check_pairs);
+		pairfree(authreq->reply_pairs);
+		pairfree(authreq->server_reply);
+		pairfree(authreq->proxy_pairs);
+		memset(authreq, 0, sizeof(AUTH_REQ));
+		free(authreq);
+        }
 }
 
 #if defined (sun) && defined(__svr4__)
